@@ -11,7 +11,7 @@ panda = Panda(generic=generic_type)
 def run_cmd():
     # First revert to root snapshot, then type a command via serial
     panda.revert_sync("root")
-    panda.record_cmd("echo test", recording_name="test")
+    panda.record_cmd("echo test && bash -c \"echo test2\"", recording_name="test")
 
     panda.end_analysis()
 
