@@ -4,7 +4,7 @@ pub type CPUArchPtr = *mut panda_sys::CPUX86State;
 #[cfg(any(feature = "arm", feature = "aarch64"))]
 pub type CPUArchPtr = *mut panda_sys::CPUARMState;
 
-#[cfg(any(feature = "mips", feature = "mipsel"))]
+#[cfg(any(feature = "mips", feature = "mipsel", feature = "mips64"))]
 pub type CPUArchPtr = *mut panda_sys::CPUMIPSState;
 
 #[cfg(feature = "ppc")]
@@ -14,5 +14,5 @@ pub type CPUArchPtr = *mut panda_sys::CPUPPCState;
 macro_rules! cpu_arch_state {
     ($cpu:expr) => {
         $cpu.env_ptr as CPUArchPtr
-    }
+    };
 }
